//go:build !windows

package dns

import (
	"net"

	"github.com/miekg/dns"
)

func getDNSHostAndPort() ([]string, error) {
	conf, err := dns.ClientConfigFromFile("/etc/resolv.conf")
	if err != nil {
		return []string{}, err
	}
	var hosts = make([]string, len(conf.Servers))
	for _, server := range conf.Servers {
		dnsIP := net.ParseIP(server)
		// add only ipv4 dns addresses
		if dnsIP != nil && dnsIP.To4() != nil {
			hosts = append(hosts, net.JoinHostPort(server, conf.Port))
		}
	}
	return hosts, nil
}
